/***************************************************************************
 $RCSfile: jobdeletedatedtransfer_be.h,v $
 -------------------
 cvs         : $Id: jobdeletedatedtransfer_be.h,v 1.4 2006/02/21 17:04:54 aquamaniac Exp $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_JOBDELETEDATEDTRANSFER_BE_H
#define AQBANKING_JOBDELETEDATEDTRANSFER_BE_H


#include <aqbanking/jobdeletedatedtransfer.h>


/** @addtogroup G_AB_JOBS_DATED_TRANSFER_DEL
 *
 */
/*@{*/

/** @name Backend Functions
 *
 * Functions in this group are only to be called by banking backends.
 */
/*@{*/

/**
 * This function lets the backend specify the limits for some of the fields
 * of a @ref AB_TRANSACTION.
 */
AQBANKING_API
void AB_JobDeleteDatedTransfer_SetFieldLimits(AB_JOB *j,
                                              AB_TRANSACTION_LIMITS *limits);
/*@}*/ 


/*@}*/ /* addtogroup */


#endif

